@@ -725,6 +725,9 @@ gchar *conv_codeset_strdup(const gchar *inbuf,
 
 	src_code = conv_get_fallback_for_private_encoding(src_code);
 	conv_func = conv_get_code_conv_func(src_code, dest_code);
+	if (conv_func == conv_ustodisp && strict_mode && !is_ascii_str(inbuf))
+		return NULL;
+
 	if (conv_func != conv_noconv) {
 		len = (strlen(inbuf) + 1) * 3;
 		buf = g_malloc(len);
@@ -1707,7 +1710,7 @@ gchar *conv_filename_from_utf8(const gchar *utf8_file)
 
 	fs_file = g_filename_from_utf8(utf8_file, -1, NULL, NULL, &error);
 	if (error) {
-		g_warning("failed to convert encoding of file name: %s\n",
+		debug_print("failed to convert encoding of file name: %s\n",
 			  error->message);
 		g_error_free(error);
 	}
