@@ -212,7 +212,7 @@ gboolean mh_scan_required(Folder *folder, FolderItem *item)
 	path = folder_item_get_path(item);
 	g_return_val_if_fail(path != NULL, FALSE);
 
-	if (stat(path, &s) < 0) {
+	if (g_stat(path, &s) < 0) {
 		FILE_OP_ERROR(path, "stat");
 		g_free(path);
 		return FALSE;
@@ -826,7 +826,7 @@ static gchar *mh_item_get_path(Folder *folder, FolderItem *item)
 	if (!is_dir_exist(real_path) && is_dir_exist(path)) {
 		/* mmh, older version did put utf8 filenames instead of
 		 * the correct encoding */
-		rename(path, real_path);
+		g_rename(path, real_path);
 		folder_item_scan(item);
 	}
 
@@ -1453,7 +1453,7 @@ static void mh_set_mtime(Folder *folder, FolderItem *item)
 
 	g_return_if_fail(path != NULL);
 
-	if (stat(path, &s) < 0) {
+	if (g_stat(path, &s) < 0) {
 		FILE_OP_ERROR(path, "stat");
 		g_free(path);
 		return;
