@@ -119,10 +119,12 @@ static void mimeview_save_as		(MimeView	*mimeview);
 static void mimeview_save_all		(MimeView	*mimeview);
 static void mimeview_launch		(MimeView	*mimeview,
 					 MimeInfo	*partinfo);
+#ifndef G_OS_WIN32
 static void mimeview_open_with		(MimeView	*mimeview);
 static void mimeview_open_part_with	(MimeView	*mimeview,
 					 MimeInfo	*partinfo,
 					 gboolean	 automatic);
+#endif
 static void mimeview_select_next_part	(MimeView	*mimeview);
 static void mimeview_select_prev_part	(MimeView	*mimeview);
 static void mimeview_view_file		(const gchar	*filename,
@@ -161,10 +163,12 @@ static void mimeview_launch_cb(GtkAction *action, gpointer data)
 	mimeview_launch(mimeview, mimeview_get_part_to_use(mimeview));
 }
 
+#ifndef G_OS_WIN32
 static void mimeview_open_with_cb(GtkAction *action, gpointer data)
 {
 	mimeview_open_with((MimeView *)data);
 }
+#endif
 
 static void mimeview_display_as_text_cb(GtkAction *action, gpointer data)
 {
@@ -189,7 +193,7 @@ static void mimeview_select_next_part_cb(GtkAction *action, gpointer data)
 static GtkActionEntry mimeview_menu_actions[] = {
 	{ "MimeView", NULL, "MimeView" },
 	{ "MimeView/Open", NULL, N_("_Open (l)"), NULL, "Open MIME part", G_CALLBACK(mimeview_launch_cb) },
-#ifndef MAEMO
+#if (!defined MAEMO && !defined G_OS_WIN32)
 	{ "MimeView/OpenWith", NULL, N_("Open _with (o)..."), NULL, "Open MIME part with...", G_CALLBACK(mimeview_open_with_cb) },
 #endif
 	{ "MimeView/DisplayAsText", NULL, N_("_Display as text (t)"), NULL, "Display as text", G_CALLBACK(mimeview_display_as_text_cb) },
@@ -250,8 +254,6 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	GtkWidget *arrow;
 	GtkWidget *scrollbutton;
 	GtkWidget *hbox;
-	GtkUIManager *gui_manager = gtkut_ui_manager();
-	GtkActionGroup *actions;
 	NoticeView *siginfoview;
 	GtkRequisition r;
 
@@ -350,27 +352,37 @@ MimeView *mimeview_create(MainWindow *mainwin)
 	ctree_mainbox = gtk_hbox_new(FALSE, 0);	
 	gtk_box_pack_start(GTK_BOX(ctree_mainbox), scrolledwin, TRUE, TRUE, 0);
 
-	actions = cm_menu_create_action_group("MimeView", mimeview_menu_actions,
+	mimeview->ui_manager = gtk_ui_manager_new();
+	mimeview->action_group = cm_menu_create_action_group_full(mimeview->ui_manager,
+			"MimeView", mimeview_menu_actions,
 			G_N_ELEMENTS(mimeview_menu_actions), (gpointer)mimeview);
 
-	MENUITEM_ADDUI("/Menus/", "MimeView", "MimeView", GTK_UI_MANAGER_MENU);
-	MENUITEM_ADDUI("/Menus/MimeView/", "Open", "MimeView/Open",
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, "/", "Menus", "Menus", GTK_UI_MANAGER_MENUBAR)
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/", "MimeView", "MimeView", GTK_UI_MANAGER_MENU);
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "Open", "MimeView/Open",
 			GTK_UI_MANAGER_MENUITEM);
-#ifndef MAEMO
-	MENUITEM_ADDUI("/Menus/MimeView/", "OpenWith", "MimeView/OpenWith",
+#if (!defined MAEMO && !defined G_OS_WIN32)
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "OpenWith", "MimeView/OpenWith",
 			GTK_UI_MANAGER_MENUITEM);
 #endif
-	MENUITEM_ADDUI("/Menus/MimeView/", "DisplayAsText", "MimeView/DisplayAsText",
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "DisplayAsText", "MimeView/DisplayAsText",
 			GTK_UI_MANAGER_MENUITEM);
-	MENUITEM_ADDUI("/Menus/MimeView/", "SaveAs", "MimeView/SaveAs",
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SaveAs", "MimeView/SaveAs",
 			GTK_UI_MANAGER_MENUITEM);
-	MENUITEM_ADDUI("/Menus/MimeView/", "SaveAll", "MimeView/SaveAll",
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "SaveAll", "MimeView/SaveAll",
 			GTK_UI_MANAGER_MENUITEM);
-	MENUITEM_ADDUI("/Menus/MimeView/", "NextPart", "MimeView/NextPart",
+	MENUITEM_ADDUI_MANAGER(mimeview->ui_manager, 
+			"/Menus/MimeView/", "NextPart", "MimeView/NextPart",
 			GTK_UI_MANAGER_MENUITEM);
 
 	popupmenu = gtk_menu_item_get_submenu(GTK_MENU_ITEM(
-				gtk_ui_manager_get_widget(gui_manager, "/Menus/MimeView")) );
+				gtk_ui_manager_get_widget(mimeview->ui_manager, "/Menus/MimeView")) );
 
 
 	vbox = gtk_vbox_new(FALSE, 0);
@@ -1301,15 +1313,17 @@ static gboolean part_button_pressed(MimeView *mimeview, GdkEventButton *event,
 		if (partinfo && (partinfo->type == MIMETYPE_MESSAGE ||
 				 partinfo->type == MIMETYPE_IMAGE ||
 				 partinfo->type == MIMETYPE_MULTIPART))
-			cm_menu_set_sensitive("MimeView/DisplayAsText", FALSE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/DisplayAsText", FALSE);
 		else
-			cm_menu_set_sensitive("MimeView/DisplayAsText", TRUE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/DisplayAsText", TRUE);
+#ifndef G_OS_WIN32
 		if (partinfo &&
 		    partinfo->type == MIMETYPE_APPLICATION &&
 		    !g_ascii_strcasecmp(partinfo->subtype, "octet-stream"))
-			cm_menu_set_sensitive("MimeView/Open", FALSE);
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/Open", FALSE);
 		else
-			cm_menu_set_sensitive("MimeView/Open", TRUE);
+#endif
+			cm_menu_set_sensitive_full(mimeview->ui_manager, "Menus/MimeView/Open", TRUE);
 
 		g_object_set_data(G_OBJECT(mimeview->popupmenu),
 				  "pop_partinfo", partinfo);
@@ -1437,11 +1451,13 @@ static gint mimeview_key_pressed(GtkWidget *widget, GdkEventKey *event,
 		KEY_PRESS_EVENT_STOP();
 		mimeview_launch(mimeview, NULL);
 		return TRUE;
+#ifndef G_OS_WIN32
 	case GDK_o:
 		BREAK_ON_MODIFIER_KEY();
 		KEY_PRESS_EVENT_STOP();
 		mimeview_open_with(mimeview);
 		return TRUE;
+#endif
 	case GDK_c:
 		BREAK_ON_MODIFIER_KEY();
 		KEY_PRESS_EVENT_STOP();
@@ -1838,6 +1854,7 @@ static void mimeview_launch(MimeView *mimeview, MimeInfo *partinfo)
 	g_free(filename);
 }
 
+#ifndef G_OS_WIN32
 static void mimeview_open_with(MimeView *mimeview)
 {
 	MimeInfo *partinfo;
@@ -1937,14 +1954,14 @@ static void mimeview_open_part_with(MimeView *mimeview, MimeInfo *partinfo, gboo
 		if (content_type != NULL)
 			cmd = input_dialog_combo_remember
 				(_("Open with"),
-				 _("Enter the command line to open file:\n"
+				 _("Enter the command-line to open file:\n"
 				   "('%s' will be replaced with file name)"),
 				 mime_command ? mime_command : prefs_common.mime_open_cmd,
 				 prefs_common.mime_open_cmd_history, &remember);
 		else
 			cmd = input_dialog_combo
 				(_("Open with"),
-				 _("Enter the command line to open file:\n"
+				 _("Enter the command-line to open file:\n"
 				   "('%s' will be replaced with file name)"),
 				 mime_command ? mime_command : prefs_common.mime_open_cmd,
 				 prefs_common.mime_open_cmd_history);
@@ -1968,10 +1985,12 @@ out:
 	g_free(content_type);
 	g_free(filename);
 }
+#endif
 
 static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			       const gchar *cmd, MimeView *mimeview)
 {
+#ifndef G_OS_WIN32
 	gchar *p;
 	gchar buf[BUFFSIZE];
 	if (cmd == NULL)
@@ -1985,7 +2004,7 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			else
 				g_chmod(filename, S_IRUSR|S_IWUSR);
  		} else {
-			g_warning("MIME viewer command line is invalid: '%s'", cmd);
+			g_warning("MIME viewer command-line is invalid: '%s'", cmd);
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
  		}
 		if (execute_command_line(buf, TRUE) != 0) {
@@ -1994,6 +2013,24 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
 		}
 	}
+#else
+	SHFILEINFO file_info;
+	if ((SHGetFileInfo(filename, 0, &file_info, sizeof(SHFILEINFO), SHGFI_EXETYPE)) != 0) {
+		AlertValue val = alertpanel_full(_("Execute untrusted binary?"), 
+				      _("This attachment is an executable file. Executing "
+				        "untrusted binaries is dangerous and could probably "
+					"lead to compromission of your computer.\n\n"
+					"Do you want to run this file?"), GTK_STOCK_CANCEL, 
+					_("Run binary"),
+		      		      NULL, FALSE, NULL, ALERT_WARNING, G_ALERTDEFAULT);
+		if (val == G_ALERTALTERNATE) {
+			debug_print("executing binary\n");
+			ShellExecute(NULL, "open", filename, NULL, NULL, SW_SHOW);
+		}
+	} else
+		ShellExecute(NULL, "open", filename, NULL, NULL, SW_SHOW);
+	
+#endif
 }
 
 void mimeview_register_viewer_factory(MimeViewerFactory *factory)
@@ -2119,10 +2156,12 @@ static gint icon_key_pressed(GtkWidget *button, GdkEventKey *event,
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_launch(mimeview, NULL);
 		return TRUE;
+#ifndef G_OS_WIN32
 	case GDK_o:
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_open_with(mimeview);
 		return TRUE;
+#endif
 	case GDK_c:
 		BREAK_ON_MODIFIER_KEY();
 		mimeview_check_signature(mimeview);
@@ -2338,15 +2377,15 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 
 static void icon_list_clear (MimeView *mimeview)
 {
-	GList     *child;
+	GList     *child, *orig;
 	GtkAdjustment *adj;
 		
-	child = gtk_container_get_children(GTK_CONTAINER(mimeview->icon_vbox));
-	for (; child != NULL; child = g_list_next(child)) {
+	orig = gtk_container_get_children(GTK_CONTAINER(mimeview->icon_vbox));
+	for (child = orig; child != NULL; child = g_list_next(child)) {
 		gtkut_container_remove(GTK_CONTAINER(mimeview->icon_vbox), 
 				       GTK_WIDGET(child->data));
 	}
-	g_list_free(child);
+	g_list_free(orig);
 	mimeview->icon_count = 0;
 	adj  = gtk_layout_get_vadjustment(GTK_LAYOUT(mimeview->icon_scroll));
 	gtk_adjustment_set_value(adj, adj->lower);
@@ -2501,8 +2540,10 @@ void mimeview_handle_cmd(MimeView *mimeview, const gchar *cmd, GdkEventButton *e
 		mimeview_save_as(mimeview);
 	else if (!strcmp(cmd, "sc://display_as_text"))
 		mimeview_display_as_text(mimeview);
+#ifndef G_OS_WIN32
 	else if (!strcmp(cmd, "sc://open_with"))
 		mimeview_open_with(mimeview);
+#endif
 	else if (!strcmp(cmd, "sc://open"))
 		mimeview_launch(mimeview, NULL);
 	else if (!strcmp(cmd, "sc://select_attachment") && data != NULL) {
