@@ -55,12 +55,12 @@
 #include "remotefolder.h"
 #include "alertpanel.h"
 #include "inc.h"
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 #  include "ssl.h"
 #endif
 
 #define NNTP_PORT	119
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 #define NNTPS_PORT	563
 #endif
 
@@ -99,7 +99,7 @@ static gchar *news_fetch_msg		(Folder		*folder,
 static void news_remove_cached_msg	(Folder 	*folder, 
 					 FolderItem 	*item, 
 					 MsgInfo 	*msginfo);
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 static Session *news_session_new	 (Folder 	*folder,
 					  const gchar	*server,
 					  gushort	 port,
@@ -281,7 +281,7 @@ static void news_session_destroy(Session *session)
 		g_free(news_session->group);
 }
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 static Session *news_session_new(Folder *folder, const gchar *server, gushort port,
 				 const gchar *userid, const gchar *passwd,
 				 SSLType ssl_type)
@@ -305,7 +305,7 @@ static Session *news_session_new(Folder *folder, const gchar *server, gushort po
 	
 	nntp_init(folder);
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	if (ssl_type != SSL_NONE)
 		r = nntp_threaded_connect_ssl(folder, server, port);
 	else
@@ -343,7 +343,7 @@ static Session *news_session_new_for_folder(Folder *folder)
 								  &(ac->session_passwd));
 	}
 
-#if (defined(USE_OPENSSL) || defined (USE_GNUTLS))
+#ifdef USE_GNUTLS
 	port = ac->set_nntpport ? ac->nntpport
 		: ac->ssl_nntp ? NNTPS_PORT : NNTP_PORT;
 	session = news_session_new(folder, ac->nntp_server, port, userid, passwd,
@@ -575,25 +575,26 @@ GSList *news_get_group_list(Folder *folder)
 			return NULL;
 		}
 		
-		for (cur = clist_begin(grouplist); cur; cur = clist_next(cur)) {
-			struct newsnntp_group_info *info = (struct newsnntp_group_info *)
-								clist_content(cur);
-			if (fprintf(fp, "%s %d %d %c\n",
-				info->grp_name,
-				info->grp_last,
-				info->grp_first,
-				info->grp_type) < 0) {
-				log_error(LOG_PROTOCOL, ("Can't write newsgroup list\n"));
-				session_destroy(SESSION(session));
-				REMOTE_FOLDER(folder)->session = NULL;
-				fclose(fp);
-				g_free(filename);
-				newsnntp_list_free(grouplist);
-				return NULL;
+		if (grouplist) {
+			for (cur = clist_begin(grouplist); cur; cur = clist_next(cur)) {
+				struct newsnntp_group_info *info = (struct newsnntp_group_info *)
+									clist_content(cur);
+				if (fprintf(fp, "%s %d %d %c\n",
+					info->grp_name,
+					info->grp_last,
+					info->grp_first,
+					info->grp_type) < 0) {
+					log_error(LOG_PROTOCOL, ("Can't write newsgroup list\n"));
+					session_destroy(SESSION(session));
+					REMOTE_FOLDER(folder)->session = NULL;
+					fclose(fp);
+					g_free(filename);
+					newsnntp_list_free(grouplist);
+					return NULL;
+				}
 			}
+			newsnntp_list_free(grouplist);
 		}
-		newsnntp_list_free(grouplist);
-
 		if (fclose(fp) == EOF) {
 			log_error(LOG_PROTOCOL, ("Can't write newsgroup list\n"));
 			session_destroy(SESSION(session));
@@ -844,6 +845,9 @@ static gchar *news_parse_xhdr(clist *hdrlist, MsgInfo *msginfo)
 {
 	struct newsnntp_xhdr_resp_item *hdr;
 	
+	if (!hdrlist)
+		return NULL;
+
 	hdr = clist_content(clist_begin(hdrlist));
 	if (hdr->hdr_article != msginfo->msgnum)
 		return NULL;
@@ -1127,28 +1131,30 @@ static GSList *news_get_msginfos_for_range(NewsSession *session, FolderItem *ite
 		return NULL;
 	}
 
-	for (cur = clist_begin(msglist); cur; cur = clist_next(cur)) {
-		struct newsnntp_xover_resp_item *ritem = (struct newsnntp_xover_resp_item *)clist_content(cur);
-		msginfo = news_parse_xover(ritem);
-		
-		if (!msginfo) {
-			log_warning(LOG_PROTOCOL, _("invalid xover line\n"));
-			continue;
-		}
+	if (msglist) {
+		for (cur = clist_begin(msglist); cur; cur = clist_next(cur)) {
+			struct newsnntp_xover_resp_item *ritem = (struct newsnntp_xover_resp_item *)clist_content(cur);
+			msginfo = news_parse_xover(ritem);
+			
+			if (!msginfo) {
+				log_warning(LOG_PROTOCOL, _("invalid xover line\n"));
+				continue;
+			}
 
-		msginfo->folder = item;
-		news_set_msg_flags(item, msginfo);
-		msginfo->flags.tmp_flags |= MSG_NEWS;
-		msginfo->newsgroups = g_strdup(item->path);
+			msginfo->folder = item;
+			news_set_msg_flags(item, msginfo);
+			msginfo->flags.tmp_flags |= MSG_NEWS;
+			msginfo->newsgroups = g_strdup(item->path);
 
-		if (!newlist)
-			llast = newlist = g_slist_append(newlist, msginfo);
-		else {
-			llast = g_slist_append(llast, msginfo);
-			llast = llast->next;
+			if (!newlist)
+				llast = newlist = g_slist_append(newlist, msginfo);
+			else {
+				llast = g_slist_append(llast, msginfo);
+				llast = llast->next;
+			}
 		}
+		newsnntp_xover_resp_list_free(msglist);
 	}
-	newsnntp_xover_resp_list_free(msglist);
 
 	news_folder_unlock(NEWS_FOLDER(item->folder));
 
