@@ -318,7 +318,7 @@ static int partial_uidl_mark_mail(MsgInfo *msginfo, int download)
 
 	fclose(fp);
 	claws_unlink(filename);
-	rename(pathnew, filename);
+	g_rename(pathnew, filename);
 	g_free(pathnew);
 	msginfo->planned_download = download;
 	msgcache_update_msg(msginfo->folder->cache, msginfo);
